#
# spec file for package uhd
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           uhd
%define libname libuhd003
Version:        3.9.7
Release:        bp153.1.24
%define src_ver 003.009.007
%define img_ver 003.009.007
Summary:        The driver for USRP SDR boards
License:        GPL-3.0-or-later
Group:          Hardware/Other
URL:            http://ettus-apps.sourcerepo.com/redmine/ettus/projects/uhd/wiki
Source0:        http://files.ettus.com/binaries/uhd_stable/uhd_%{src_ver}-release/uhd_%{version}-release.tar.gz
Source1:        http://files.ettus.com/binaries/images/uhd-images_%{img_ver}-release.tar.xz
# PATCH-FIX-OPENSUSE fix-for-armv6l-armv7l-build-failure.patch
Patch0:         fix-for-armv6l-armv7l-build-failure.patch
# PATCH-FIX-OPENSUSE uhd-fix-for-boost-1_66.patch
Patch1:         uhd-fix-for-boost-1_66.patch
Patch2:         uhd-fix-for-boost-1_67.patch
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_serialization-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
BuildRequires:  libboost_thread-devel
# WORKAROUND: force docutils to use python 2
BuildRequires:  python2-docutils
%else
BuildRequires:  boost-devel >= 1.36.0
%endif
BuildRequires:  cmake >= 2.6
BuildRequires:  docutils
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gpsd-devel
BuildRequires:  memory-constraints
BuildRequires:  orc
BuildRequires:  pkg-config
BuildRequires:  python-Mako >= 0.4
BuildRequires:  python-cheetah >= 2.0.0
BuildRequires:  python-devel >= 2.6
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(udev)
Requires:       udev
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The UHD is the "Universal Software Radio Peripheral" hardware driver.
The goal of the UHD is to provide a host driver and API for current
and future Ettus Research products. Users will be able to use the
UHD driver standalone or with 3rd party applications.

%package     -n %{libname}
Summary:        The UHD driver
Group:          Hardware/Other
Requires:       %{name}-udev >= %{version}
# PRE script requires /usr/sbin/groupadd, that exists in the "shadow" package
Requires(pre):  shadow 

%description -n %{libname}
The UHD is the "Universal Software Radio Peripheral" hardware driver.
The goal of the UHD is to provide a host driver and API for current
and future Ettus Research products. Users will be able to use the
UHD driver standalone or with 3rd party applications.

%package        udev
Summary:        UHD udev rules
Group:          Hardware/Other

%description    udev
The UHD is the "Universal Software Radio Peripheral" hardware driver.
The goal of the UHD is to provide a host driver and API for current
and future Ettus Research products. Users will be able to use the
UHD driver standalone or with 3rd party applications.

This package contains udev rules for UHD.

%package        devel
Summary:        Development files for uhd
Group:          Development/Libraries/Other
Requires:       %{libname} = %{version}
%if 0%{?suse_version} > 1325
Requires:       libboost_filesystem-devel
Requires:       libboost_program_options-devel
Requires:       libboost_regex-devel
Requires:       libboost_serialization-devel
Requires:       libboost_test-devel
Requires:       libboost_thread-devel
%else
Requires:       boost-devel
%endif
Recommends:     %{name}-doc

%description    devel
The UHD is the "Universal Software Radio Peripheral" hardware driver.
The goal of the UHD is to provide a host driver and API for current
and future Ettus Research products. Users will be able to use the
UHD driver standalone or with 3rd party applications.

This package contains all the necessary tools, examples and include
files for development with the UHD Driver.

%package        doc
Summary:        Documentation files for uhd
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
This package contains the documentation for the Universal Hardware Driver (UHD).

%package        firmware
Summary:        Firmware images for uhd
Group:          Hardware/Other
Requires:       %{libname} = %{version}
BuildArch:      noarch

%description    firmware
This package contains binary firmware images for the Universal Hardware Driver (UHD).

%prep
%setup -q -n %{name}_%{version}-release
%patch0 -p1
%patch1 -p1
%patch2 -p1

# remove buildtime from documentation
echo "HTML_TIMESTAMP         = NO" >> docs/Doxyfile.in

%build
touch ../README.md
%limit_build
%cmake \
  -DPYTHON_EXECUTABLE=/usr/bin/python2 \
  -DENABLE_GPSD=0
%make_jobs

%check
%ctest

%install
%cmake_install

# Fix udev rules and allow access only to users in usrp group
sed -i 's/BUS==/SUBSYSTEM==/;s/SYSFS{/ATTRS{/;s/MODE:="0666"/GROUP:="usrp", MODE:="0660"/' %{buildroot}%{_libdir}/uhd/utils/uhd-usrp.rules
install -m 0644 -D %{buildroot}%{_libdir}/uhd/utils/uhd-usrp.rules %{buildroot}%{_udevrulesdir}/10-usrp-uhd.rules
rm %{buildroot}%{_libdir}/uhd/utils/uhd-usrp.rules

# Move documentation at the default docdir
mkdir -p  %{buildroot}%{_docdir}/uhd
mv %{buildroot}%{_datadir}/doc/uhd %{buildroot}%{_docdir}/
mv %{buildroot}%{_libdir}/uhd/utils/*[!.rules] %{buildroot}%{_bindir}
mv %{buildroot}%{_libdir}/uhd/examples/* %{buildroot}%{_bindir}
mv %{buildroot}%{_libdir}/uhd/tests/*_test %{buildroot}%{_bindir}

rm -rf %{buildroot}%{_libdir}/uhd/tests
rm -rf %{buildroot}%{_libdir}/uhd/examples

rm -rf %{buildroot}%{_docdir}/uhd/LICENSE
rm -rf %{buildroot}%{_docdir}/uhd/README.md

# two executable files are installed to /usr/share/uhd
mv %{buildroot}%{_libdir}/uhd/utils/query_gpsdo_sensors %{buildroot}%{_bindir}
mv %{buildroot}%{_libdir}/uhd/utils/usrp_n2xx_simple_net_burner %{buildroot}%{_bindir}
mv %{buildroot}%{_libdir}/uhd/utils/b2xx_fx3_utils %{buildroot}%{_bindir}
mv %{buildroot}%{_libdir}/uhd/utils/usrp_x3xx_fpga_burner %{buildroot}%{_bindir}

# extract firmware
mkdir -p %{buildroot}%{_datadir}/uhd
tar -xJvf %{SOURCE1} --transform="s,^uhd-images_%{img_ver}-release/share/uhd/,," --show-transformed-names -C %{buildroot}%{_datadir}/uhd

# find dupes
%fdupes -s %{buildroot}%{_prefix}

%pre -n %{libname}
getent group usrp >/dev/null || %{_sbindir}/groupadd -r usrp

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc LICENSE
%{_libdir}/*.so.*.*

%files udev
%defattr(-,root,root)
%{_udevrulesdir}/10-usrp-uhd.rules

%files devel
%defattr(-,root,root)
%dir %{_includedir}/uhd
%dir %{_datadir}/uhd
%exclude %{_datadir}/uhd/images
%{_includedir}/uhd/*
%{_includedir}/uhd.h
%{_bindir}/*
%{_libdir}/libuhd.so
%{_libdir}/libuhd.so.003
%{_libdir}/pkgconfig/uhd.pc
%{_libdir}/cmake/uhd
%{_mandir}/man1/*

%files firmware
%defattr(-,root,root)
%{_datadir}/uhd/images/

%files doc
%defattr(-,root,root)
%dir %{_docdir}/uhd
%{_docdir}/uhd/doxygen
#{_docdir}/uhd/manual

%changelog
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through -mini flavors.
* Sat Mar 23 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Fixed build for Boost 1.69
* Fri Dec 28 2018 mardnh@gmx.de
- Disable support for GPSD in uhd for now.
  gps support is not yet adapted to the latest gpsd API.
* Tue May 29 2018 adam.majer@suse.de
- fixed build with Boost 1.67 (bsc#1089820)
  uhd-fix-for-boost-1_67.patch
- drop _constraints and use memory-constraints package instead.
- re-enabled package tests
* Sat Jan 13 2018 mardnh@gmx.de
- Force usage of python2 during build
* Wed Jan  3 2018 mardnh@gmx.de
- Adjust _constraints to set required memory to 6Gb
* Thu Dec 28 2017 wk@ire.pw.edu.pl
- fixed build with boost-1.66
  patch uhd-fix-for-boost-1_66.patch backported from git
* Fri Jul 21 2017 wk@ire.pw.edu.pl
- Updated sources to version 3.9.7
- enabled GPSD support
* Thu May  4 2017 wk@ire.pw.edu.pl
- Force docutils to use python2 on Tumbleweed
* Fri Feb  3 2017 jengelh@inai.de
- Directly invoke ldconfig and don't suppress output from groupadd.
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Tue Dec 13 2016 victhor.foster@gmail.com
- Add fix-for-armv6l-armv7l-build-failure.patch, adds -mfpu=neon compiler flag to package
  Fixes build failure on armv6l and armv7l architectures
* Sat Sep  3 2016 wk@ire.pw.edu.pl
- Update sources to version 3.9.5
* Sun Jul  3 2016 opensuse.lietuviu.kalba@gmail.com
- %%pre script requires /usr/sbin/groupadd from "shadow" package
* Sat May  7 2016 wk@ire.pw.edu.pl
- Update sources to version 3.9.4
* Wed Mar 23 2016 wk@ire.pw.edu.pl
- Update sources to version 3.9.3
* Thu Dec 31 2015 wk@ire.pw.edu.pl
- Update sources to version 3.9.2
- Drop 0003-uhd-C-API-wrapper-fix-commit-30f87afcba71a07.patch:
  included upstream
* Sun Dec 27 2015 mardnh@gmx.de
- Add patch for correctly installing the C-API header files
  * 0003-uhd-C-API-wrapper-fix-commit-30f87afcba71a07.patch
* Sat Sep 26 2015 wk@ire.pw.edu.pl
- Update sources to version 3.9.1
- arm-neon.patch patch removed
* Thu Sep 10 2015 wk@ire.pw.edu.pl
- Update sources to version 3.9.0
* Tue Aug 18 2015 wk@ire.pw.edu.pl
- Update sources to version 3.8.5
* Wed Aug 12 2015 schwab@suse.de
- arm-neon.patch: don't use 32-bit arm code on 64-bit arm
* Sat Jun 20 2015 dmitry_r@opensuse.org
- Add _constraints to set required memory to 3Gb
* Sat May 16 2015 wk@ire.pw.edu.pl
- Update sources to version 3.8.4
* Wed Feb 18 2015 wk@ire.pw.edu.pl
- Update sources to version 3.8.2
* Thu Jan 29 2015 wk@ire.pw.edu.pl
- Update to version 3.8.1
  * firmware images are from 3.8.2
* Thu Oct 23 2014 wk@ire.pw.edu.pl
- Update to version 3.7.3
  * firmware images are from 3.7.2
* Mon Sep  1 2014 wk@ire.pw.edu.pl
- Update to version 3.7.2
  * bugfix release
* Wed Aug 20 2014 dmitry_r@opensuse.org
- Cleanup spec file
- Remove OBS source service
- Use %%cmake macros
- Move udev rules to uhd-udev package according to shared library
  packaging policy
- Remove buildtime from documentation
* Wed Apr  2 2014 wk@ire.pw.edu.pl
- Update to version 3.7.0
* Thu Jan 30 2014 lnt-sysadmin@lists.lrz.de
- Changes to spec file:
  * Use full path when calling groupadd
* Wed Jan 29 2014 opensuse@dstoecker.de
- uhd-devel needs boost
* Sun Nov  3 2013 lnt-sysadmin@lists.lrz.de
- Update to version 3.5.4
- Changes to spec file:
  * Update udev paths for openSUSE 13.1 and ensure udev rules are
    updated when package is installed / updated / uninstalled.
  * Add %%check section (currently disabled due to failures in 13.1)
  * Find file dupes also in %%_bindir
* Fri Apr 12 2013 lnt-sysadmin@lists.lrz.de
- Update to version 3.5.2
- Added Ettus firmware images (version 3.5.2)
- Changes to spec file:
  * pass %%optflags to cmake according to
    http://en.opensuse.org/openSUSE:Build_system_recipes
  * fixed search for duplicate files
* Wed Nov  7 2012 wk@ire.pw.edu.pl
- updated to 3.5.0
- fixed some rpmlint warnings
* Tue Oct 23 2012 wk@ire.pw.edu.pl
- install udev rule (from Fedora)
* Sun Oct 21 2012 wk@ire.pw.edu.pl
- updated to 3.4.3
* Fri Jun 15 2012 surligas@csd.uoc.gr
- packaged libuhd version 3.4.2
